<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  Top Event
 * @since  Top Event 1.0.0
 * @return array An array of default values
 */

function top_event_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$top_event_default_options = array(
		// Color Options
		'header_title_color'			    => '#fff',
		'header_tagline_color'			    => '#fff',
		'header_txt_logo_extra'			    => 'show-all',

		// loader

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
				
		// homepage options
		'enable_frontpage_content' 			=> false,

		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'top-event' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	    => (bool) true,

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'sortable' 						    => 'slider,about,promotion,event,latest_post',
		
		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'top-event' ),
		'blog_column'						=> 'col-2',
		'hide_date' 					    => (bool) false,


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,
		'single_post_hide_category'		    => (bool) false,
		'single_post_hide_tags'			    => (bool) false,

		/* Front Page */

		// Slider
		'slider_section_enable'				=> (bool) false,
		'slider_content_type'				=> 'page',
		'slider_count'						=> 3,
		'slider_btn_txt'                    => esc_html__('Learn More','top-event'),
		'slider_btn_alt_txt'                => esc_html__('Buy Tickets','top-event'),
	
		//about 
		'about_section_enable'			    => (bool) false,
		'about_content_type'			    =>'page',
		'about_section_subtitle'			=> esc_html__('Welcome to the dedicated to building remarkable Schedule!','top-event'),
		'about_section_title'				=> esc_html__('HAPPY NEW YEAR 2021','top-event'),
		'about_excerpt_length'				=> 100,
		'about_btn_txt'                     => esc_html__('Learn More','top-event'),
		
		// latest_post
		'latest_post_section_enable'		    => (bool) false,
		'latest_post_title'					    => esc_html__( 'Event Blogs', 'top-event' ),
		'latest_post_sub_title'          		=> esc_html__('Welcome to the dedicated to building remarkable Schedule!','top-event'),
		'latest_post_count'					    => 2,

		// event
		'event_section_enable'				=> (bool) false,
		'event_sub_title'				    => esc_html__( 'Welcome to the dedicated to building remarkable Schedule!', 'top-event' ),
		'event_title'					    => esc_html__( 'EVENT SCHEDULE', 'top-event' ),
		'event_content_type'				=> 'page',
		'event_count'						=> 6,
	
		//promotion
		'promotion_section_enable' 		=> false,
		'promotion_content_type'		=> 'page',
		'promotion_excerpt_length'		=>	10,
				
	);

	$output = apply_filters( 'top_event_default_theme_options', $top_event_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}