<?php
/**
 * Banner section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage Top Event
 * @since Top Event 1.0.0
 */
if ( ! function_exists( 'top_event_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since Top Event 1.0.0
    */
    function top_event_add_about_section() {
    	$options = top_event_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'top_event_section_status', true, 'about_section_enable' ) ;
        
        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'top_event_filter_about_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render about section now.
        top_event_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_event_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since Top Event 1.0.0
    * @param array $input about section details.
    */
    function top_event_get_about_section_details( $input ) {
        $options = top_event_get_theme_options();

        // Content type.
        $content = array();
        
        $page_id = '';
        if ( ! empty( $options['about_content_page'] ) )
            $page_id = isset($options['about_content_page']) ? $options['about_content_page'] : '' ;
        $args = array(
            'post_type'             => 'page',
            'p'                     =>  absint( $page_id ),
            'ignore_sticky_posts'   => true,
        );

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['excerpt']   = top_event_trim_content($options['about_excerpt_length']);
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink( );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'top_event_filter_about_section_details', 'top_event_get_about_section_details' );


if ( ! function_exists( 'top_event_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since Top Event 1.0.0
   *
   */
   function top_event_render_about_section( $content_details = array() ) {
        $options        = top_event_get_theme_options();
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php $content = $content_details[0];?>

            <div id="about-section" class="relative page-section same-background">
                <div class="wrapper">
                    <div class="section-header">
                        <h2 class="section-title"><?php echo esc_html($options['about_section_title']); ?></h2>
                        <p class="section-subtitle"><?php echo esc_html($options['about_section_subtitle']); ?></p>
                    </div><!-- .section-header -->

                    <article class="has-post-thumbnail">
                        <div class="featured-image">
                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url($content['image']); ?>" alt="<?php echo esc_attr($content['title']); ?>"></a>
                        </div><!-- .featured-image -->

                        <div class="entry-container">
                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                            </header><!-- .section-header -->

                            <div class="entry-content">
                                <p><?php echo wp_kses( $content['excerpt'],
                                                array(
                                                    'a'      => array(
                                                        'href'  => array(),
                                                        'title' => array(),
                                                    ),
                                                    'br'     => array(),
                                                    'em'     => array(),
                                                    'strong' => array(),
                                                    'blockquote' => array(),
                                                )
                                            ); ?>
                                </p>
                            </div><!-- .entry-content -->

                            <?php if(!empty($options['about_btn_txt'])) :?>
                                <div class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn"><?php echo esc_html($options['about_btn_txt'])?></a>
                                </div><!-- .read-more -->
                            <?php endif; ?>
                        </div><!-- .entry-container -->
                    </article>
                </div><!-- .wrapper -->
            </div><!-- #about-us -->
     
    <?php
    }    
endif;