<?php
/**
 * Latest Post section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage  Top Event
 * @since  Top Event 1.0.0
 */
if ( ! function_exists( 'top_event_add_latest_post_section' ) ) :
    /**
    * Add Latest Post section
    *
    *@since  Top Event 1.0.0
    */
    function top_event_add_latest_post_section() {
        $options = top_event_get_theme_options();
        // Check if Latest Post is enabled on frontpage
        $latest_post_enable = apply_filters( 'top_event_section_status', true, 'latest_post_section_enable' );

        if ( true !== $latest_post_enable ) {
            return false;
        }
        // Get Latest Post section details
        $section_details = array();
        $section_details = apply_filters( 'top_event_filter_latest_post_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }
        // Render Latest Post section now.
        top_event_render_latest_post_section( $section_details );
    }
endif;

if ( ! function_exists( 'top_event_get_latest_post_section_details' ) ) :
    /**
    * Latest Post section details.
    *
    * @since  Top Event 1.0.0
    * @param array $input Latest Post section details.
    */
    function top_event_get_latest_post_section_details( $input ) {
        $options = top_event_get_theme_options();

        // Content type.
        $latest_post_count = ! empty( $options['latest_post_count'] ) ? $options['latest_post_count'] : 2;
        
        $content = array();
        $cat_id = ! empty( $options['latest_post_content_category'] ) ? $options['latest_post_content_category'] : '';
        $args = array(
            'post_type'             => 'post',
            'posts_per_page'        => absint( $latest_post_count ),
            'cat'                   => absint( $cat_id ),
            'ignore_sticky_posts'   => true,
        );      
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = top_event_trim_content( 30);
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'top_event_filter_latest_post_section_details', 'top_event_get_latest_post_section_details' );


if ( ! function_exists( 'top_event_render_latest_post_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since  Latest Post Press Pro 1.0.0
   *
   */
   function top_event_render_latest_post_section( $content_details = array() ) {
        $options                = top_event_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="latest-posts-section" class="relative page-section same-background">
            <div class="wrapper">
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html($options['latest_post_title'])?></h2>
                    <p class="section-subtitle"><?php echo esc_html($options['latest_post_sub_title'])?></p>
                </div><!-- .section-header -->

                <div class="archive-blog-wrapper col-2 clear">
                    <?php foreach ($content_details as $content):?>

                    <article>
                        <div class="post-wrapper">
                            <div class="featured-image">
                                <a href="<?php echo esc_url($content['url']);?>"><img src="<?php echo esc_url($content['image']);?>" alt="<?php echo esc_attr($content['title']); ?>"></a>
                            </div><!-- .featured-image -->

                            <div class="entry-container">
                                <?php top_event_posted_on($content['id']); ?>


                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>" tabindex="0"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['excerpt']);?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </div><!-- .post-wrapper -->
                    </article>
                    <?php endforeach; ?>

                </div><!-- .archive-blog-wrapper -->
            </div><!-- .wrapper -->
        </div><!-- #latest-posts-section -->

<?php }
endif;  ?>