<?php
/**
 * Banner section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage  Top Event
 * @since  Top Event 1.0.0
 */
if ( ! function_exists( 'top_event_add_slider_section' ) ) :
    /**
    * Add slider section
    *
    *@since  Top Event 1.0.0
    */
    function top_event_add_slider_section() {
    	$options = top_event_get_theme_options();
        // Check if slider is enabled on frontpage
        $slider_enable = apply_filters( 'top_event_section_status', true, 'slider_section_enable' );

        if ( true !== $slider_enable ) {
            return false;
        }
        // Get slider section details
        $section_details = array();
        $section_details = apply_filters( 'top_event_filter_slider_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render slider section now.
        top_event_render_slider_section( $section_details );
}

endif;

if ( ! function_exists( 'top_event_get_slider_section_details' ) ) :
    /**
    * slider section details.
    *
    * @since  Top Event 1.0.0
    * @param array $input slider section details.
    */
    function top_event_get_slider_section_details( $input ) {
        $options = top_event_get_theme_options();

        // Content type.
        $slider_content_type    = $options['slider_content_type'];
        $slider_count           = ! empty( $options['slider_count'] ) ? $options['slider_count'] : 3;
        
        $content = array();
        switch ( $slider_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_page_' . $i] ) )
                        $page_ids[] = $options['slider_content_page_' . $i];
                }

                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'event':
                $event_ids = array();

                for ( $i = 1; $i <= $slider_count; $i++ ) {
                    if ( ! empty( $options['slider_content_event_' . $i] ) )
                        $event_ids[] = $options['slider_content_event_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'tp-event',
                    'post__in'          => ( array ) $event_ids,
                    'posts_per_page'    => absint( $slider_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            default:
            break;
        }

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            $i = 1;
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = top_event_trim_content( 20 );
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'large' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
            $i++;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// slider section content details.
add_filter( 'top_event_filter_slider_section_details', 'top_event_get_slider_section_details' );


if ( ! function_exists( 'top_event_render_slider_section' ) ) :
  /**
   * Start slider section
   *
   * @return string slider content
   * @since  Top Event 1.0.0
   *
   */
   function top_event_render_slider_section( $content_details = array() ) {
        $options = top_event_get_theme_options();
        $slider_content_type    = $options['slider_content_type'];


        if ( empty( $content_details ) ) {
            return;
        } ?>

        
        <div id="featured-slider-section" class="slider-section">
            <div class="featured-slider"
                data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 800, "dots": true, "arrows": false, "autoplay": true, "draggable": true, "fade": false, "adaptiveHeight": true, "fade": true }'>
                <?php foreach ( $content_details as $key => $content ) : ?>
                <article style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                    <div class="overlay"></div>
                    <div class="wrapper">
                        <div class="featured-content-wrapper">
                            <div class="entry-container">
                                <header class="entry-header">
                                    <h2 class="entry-title">
                                        <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a>
                                    </h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo ($slider_content_type == 'event') ? tp_event_location( $content['id'] ) :  wp_kses_post($content['excerpt']); ?></p>
                                </div><!-- .entry-content -->

                                <?php if(!empty($options['slider_btn_txt']) && !empty($options['slider_btn_alt_txt'])): ?>
                                <div class="read-more">
                                    <?php if(!empty($options['slider_btn_txt'])): ?>
                                        <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['slider_btn_txt']); ?></a>
                                    <?php endif; ?>

                                    <?php if(!empty($options['slider_btn_alt_txt']) && !empty($options['slider_btn_alt_url_' . (absint($key)+1) ]) ): ?>
                                        <a href="<?php echo esc_url($options['slider_btn_alt_url_' . (absint($key)+1) ]); ?>" class="btn"><?php echo esc_html($options['slider_btn_alt_txt']); ?></a>
                                    <?php endif; ?>
                                </div><!-- .read-more -->
                                <?php endif; ?>
                            </div><!-- .entry-container -->
                        </div><!-- .featured-content-wrapper -->
                    </div><!-- .wrapper -->
                </article>
                <?php endforeach; ?>
            </div><!-- .featured-slider -->
        </div><!-- #featured-slider-section -->

<?php
    }    
endif;